package com.jiuqi.dna.ide.designer.toolkit;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import org.eclipse.gef.palette.PaletteEntry;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

/* loaded from: com_jiuqi_dna_ide_designer_toolkit.jar:com/jiuqi/dna/ide/designer/toolkit/ToolkitElement.class */
public class ToolkitElement implements Serializable, Comparable<ToolkitElement> {
    private static final long serialVersionUID = -4192379224031265410L;
    private String id;
    private String name;
    private String type;
    private String smallIconUrl;
    private ImageDescriptor smallIcon;
    private Image smallIconImage;
    private String largeIconUrl;
    private ImageDescriptor largeIcon;
    private String imageUrl;
    private Image image;
    private String description;
    private String customEditorClassPath;
    private PaletteEntry toolEntry;
    private String catalog = "";
    private String group = "";
    private boolean visible = true;
    private boolean containable = false;
    private ArrayList<PropertyDescriptor> propertyDescriptors = new ArrayList<>();
    private ArrayList<String> styles = new ArrayList<>();
    private ArrayList<String> events = new ArrayList<>();

    public String getId() {
        return this.id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getCatalog() {
        return this.catalog;
    }

    public void setCatalog(String catalog) {
        if (catalog == null) {
            this.catalog = "";
        } else {
            this.catalog = catalog;
        }
    }

    public String getGroup() {
        return this.group;
    }

    public void setGroup(String group) {
        if (group == null) {
            this.group = "";
        } else {
            this.group = group;
        }
    }

    public boolean isVisible() {
        return this.visible;
    }

    public void setVisible(boolean visible) {
        this.visible = visible;
    }

    public boolean isContainable() {
        return this.containable;
    }

    public void setContainable(boolean containable) {
        this.containable = containable;
    }

    public String getSmallIconUrl() {
        return this.smallIconUrl;
    }

    public void setSmallIconUrl(String smallIconUrl) {
        this.smallIconUrl = smallIconUrl;
    }

    public String getLargeIconUrl() {
        return this.largeIconUrl;
    }

    public void setLargeIconUrl(String largeIconUrl) {
        this.largeIconUrl = largeIconUrl;
    }

    public String getImageUrl() {
        return this.imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getDescription() {
        return this.description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public void addPropertyDescriptor(PropertyDescriptor propertyDescriptor) {
        this.propertyDescriptors.add(propertyDescriptor);
    }

    public void removePropertyDescriptor(PropertyDescriptor propertyDescriptor) {
        this.propertyDescriptors.remove(propertyDescriptor);
    }

    public ArrayList<PropertyDescriptor> getPropertyDescriptors() {
        return this.propertyDescriptors;
    }

    public PropertyDescriptor getPropertyDescriptor(String propertyName) {
        if (propertyName == null) {
            throw new NullPointerException("元素属性名propertyName不能为NULL");
        }
        Iterator<PropertyDescriptor> it = this.propertyDescriptors.iterator();
        while (it.hasNext()) {
            PropertyDescriptor descriptor = it.next();
            if (propertyName.equals(descriptor.getPropertyName())) {
                return descriptor;
            }
        }
        return null;
    }

    public boolean hasCustomEditor() {
        return this.customEditorClassPath != null;
    }

    public String getCustomEditorClassPath() {
        return this.customEditorClassPath;
    }

    public void setCustomEditorClassPath(String classPath) {
        this.customEditorClassPath = classPath;
    }

    public ArrayList<String> getStyles() {
        return this.styles;
    }

    public void setStyles(ArrayList<String> styles) {
        this.styles = styles;
    }

    public void addStyle(String styleName) {
        this.styles.add(styleName);
    }

    public void removeStyle(String styleName) {
        this.styles.remove(styleName);
    }

    public ArrayList<String> getEvents() {
        return this.events;
    }

    public void setEvents(ArrayList<String> events) {
        this.events = events;
    }

    public void addEvent(String eventName) {
        this.events.add(eventName);
    }

    public void removeEvent(String eventName) {
        this.events.remove(eventName);
    }

    public ImageDescriptor getSmallIcon() {
        return this.smallIcon;
    }

    public void setSmallIcon(ImageDescriptor icon) {
        if (this.toolEntry != null) {
            this.toolEntry.setSmallIcon(icon);
        }
        this.smallIcon = icon;
    }

    public ImageDescriptor getLargeIcon() {
        return this.largeIcon;
    }

    public void setLargeIcon(ImageDescriptor largeIcon) {
        if (this.toolEntry != null) {
            this.toolEntry.setLargeIcon(largeIcon);
        }
        this.largeIcon = largeIcon;
    }

    public Image getImage() {
        return this.image;
    }

    public void setImage(Image image) {
        this.image = image;
    }

    @Override // java.lang.Comparable
    public int compareTo(ToolkitElement element) {
        if (this == element) {
            return 0;
        }
        return this.id.compareTo(element.id);
    }

    public Image getSmallIconImage() {
        if (this.smallIconImage == null) {
            this.smallIconImage = this.smallIcon.createImage();
        }
        return this.smallIconImage;
    }

    public void setToolEntry(PaletteEntry toolEntry) {
        this.toolEntry = toolEntry;
    }
}
